summaryrefslogtreecommitdiff
path: root/include/llvm/MC/MCInstPrinter.h
diff options
context:
space:
mode:
authorRafael Espindola <rafael.espindola@gmail.com>2011-06-02 02:34:55 +0000
committerRafael Espindola <rafael.espindola@gmail.com>2011-06-02 02:34:55 +0000
commitcde4ce411b1ace4a80ea1dd38df97e8508aed0c9 (patch)
treea560b88834f814357d15c130319ef3d70502ca94 /include/llvm/MC/MCInstPrinter.h
parent491a13691d3b30b8288dfc6e01ad6a58f69a4ce6 (diff)
downloadllvm-cde4ce411b1ace4a80ea1dd38df97e8508aed0c9.tar.gz
llvm-cde4ce411b1ace4a80ea1dd38df97e8508aed0c9.tar.bz2
llvm-cde4ce411b1ace4a80ea1dd38df97e8508aed0c9.tar.xz
Don't hardcode the %reg format in the streamer.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@132451 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/MC/MCInstPrinter.h')
-rw-r--r--include/llvm/MC/MCInstPrinter.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/MC/MCInstPrinter.h b/include/llvm/MC/MCInstPrinter.h
index 066955867c..39002dabca 100644
--- a/include/llvm/MC/MCInstPrinter.h
+++ b/include/llvm/MC/MCInstPrinter.h
@@ -45,8 +45,8 @@ public:
/// "MOV32ri") or empty if we can't resolve it.
virtual StringRef getOpcodeName(unsigned Opcode) const;
- /// getRegName - Return the assembler register name.
- virtual StringRef getRegName(unsigned RegNo) const;
+ /// printRegName - Print the assembler register name.
+ virtual void printRegName(raw_ostream &OS, unsigned RegNo) const;
unsigned getAvailableFeatures() const { return AvailableFeatures; }
void setAvailableFeatures(unsigned Value) { AvailableFeatures = Value; }